# Changelog

## [0.8.0a1](https://github.com/OpenVoiceOS/ovos-utils/tree/0.8.0a1) (2025-05-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/0.7.1...0.8.0a1)

**Merged pull requests:**

- feat: ignore\_case flag in fuzzy\_match utils [\#329](https://github.com/OpenVoiceOS/ovos-utils/pull/329) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
